OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Favorites" : "விருப்பங்கள்",
    "Shared with you" : "Shared with you",
    "Tags" : "சீட்டுகள்",
    "Back" : "பின்னுக்கு",
    "Save" : "சேமிக்க ",
    "Favorite" : "விருப்பமான",
    "Home" : "அகம்",
    "General" : "பொதுவான",
    "Remove from favorites" : "Remove from favorites",
    "Details" : "விவரங்கள்",
    "Cancel" : "Cancel",
    "Group" : "Group",
    "Add" : "சேர்க்க"
},
"nplurals=2; plural=(n != 1);");
